==================
EZID Python Client
==================

A Python client to ease programmatic use of the EZID web api.

Currently, the module also provides the same client interface as the sample
code in http://n2t.net/ezid/doc/apidoc.html and borrows heavily from it.

See https://bitbucket.org/mredar/ezid for most current source
